@@ -16,6 +16,7 @@ my %os_class = (
      win32   => "Win32",
      msdos   => "FAT",
      dos     => "FAT",
+     qnx     => "QNX",
 );
 
 sub os_class
@@ -24,7 +25,7 @@ sub os_class
 
     my $class = "URI::file::" . ($os_class{$OS} || "Unix");
     no strict 'refs';
-    unless (defined %{"$class\::"}) {
+    unless (%{"$class\::"}) {
 	eval "require $class";
 	die $@ if $@;
     }
@@ -52,7 +53,9 @@ sub cwd
 {
     my $class = shift;
     require Cwd;
-    my $cwd = $class->new(Cwd::cwd());
+    my $cwd = Cwd::cwd();
+    $cwd = VMS::Filespec::unixpath($cwd) if $^O eq 'VMS';
+    $cwd = $class->new($cwd);
     $cwd .= "/" unless substr($cwd, -1, 1) eq "/";
     $cwd;
 }
@@ -140,7 +143,7 @@ the common and generic methods described in L<URI>):
 This method return a file name.  It maps from the URI name space
 to the file name space of the indicated operating system.
 
-It might return U<undef> if the name can not be represented in the
+It might return C<undef> if the name can not be represented in the
 indicated file system.
 
 =item $u->dir( [$os] )
